mailr14012 - in /branches/gui_testing: ./ relax_errors.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on July 29, 2011 - 19:03:
Author: bugman
Date: Fri Jul 29 19:03:43 2011
New Revision: 14012

URL: http://svn.gna.org/viewcvs/relax?rev=14012&view=rev
Log:
Merged revisions 14011 via svnmerge from 
svn+ssh://bugman@xxxxxxxxxxx/svn/relax/1.3

........
  r14011 | bugman | 2011-07-29 19:01:35 +0200 (Fri, 29 Jul 2011) | 5 lines
  
  The relax state is now saved on a RelaxError when the pedantic rather than 
debugging flag is turned on.
  
  As both flags can be given, this allows for this state saving to be 
activated or deactivated.
........

Modified:
    branches/gui_testing/   (props changed)
    branches/gui_testing/relax_errors.py

Propchange: branches/gui_testing/
------------------------------------------------------------------------------
--- svnmerge-integrated (original)
+++ svnmerge-integrated Fri Jul 29 19:03:43 2011
@@ -1,1 +1,1 @@
-/1.3:1-14009
+/1.3:1-14011

Modified: branches/gui_testing/relax_errors.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/relax_errors.py?rev=14012&r1=14011&r2=14012&view=diff
==============================================================================
--- branches/gui_testing/relax_errors.py (original)
+++ branches/gui_testing/relax_errors.py Fri Jul 29 19:03:43 2011
@@ -97,9 +97,9 @@
     def __str__(self):
         """Modify the behaviour of the error system."""
 
         # Save the state if debugging is turned on.
         from status import Status; status = Status()
-        if status.debug:
+        if status.pedantic:
             save_state()
 
         # Modify the error message to include 'RelaxError' at the start.
@@ -97,9 +97,9 @@
         """Modify the behaviour of the error system."""
 
-        # Save the state if debugging is turned on.
+        # Save the state if the pedantic flag is turned on.
         from status import Status; status = Status()




Related Messages


Powered by MHonArc, Updated Fri Jul 29 19:20:02 2011